#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2013 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


"""Reports plugin."""


import os
import gettext
_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-setup')


from otopi import util
from otopi import plugin


from ovirt_engine_setup import constants as osetupcons
from ovirt_engine_setup import rhevm_constants as rhevmcons


@util.export
class Plugin(plugin.PluginBase):
    """Reports plugin."""

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_CLOSEUP,
        before=(
            osetupcons.Stages.DIALOG_TITLES_E_SUMMARY,
        ),
        after=(
            osetupcons.Stages.DIALOG_TITLES_S_SUMMARY,
        ),
        priority=plugin.Stages.PRIORITY_LAST,
    )
    def _closeup(self):
        packages = []
        if os.path.exists(
            rhevmcons.FileLocations.DWH_INSTALLATION_FOLDER
        ):
            packages.append('rhevm-dwh')

        if os.path.exists(
            rhevmcons.FileLocations.REPORTS_INSTALLATION_FOLDER
        ):
            packages.append('rhevm-reports')

        if packages:
            self.logger.info(
                _('DWH and/or Reports were found on this system.')
            )
            self.dialog.note(
                text=_(
                    'To upgrade them, please run the following commands:\n'
                    '# yum update {packages}\n'
                    '{setup}'
                ).format(
                    packages=' '.join(packages),
                    setup='\n'.join(
                        [_('# {p}-setup').format(p=p) for p in packages]
                    ),
                )
            )


# vim: expandtab tabstop=4 shiftwidth=4
